@@ -51,7 +51,7 @@ size_t R_curl_callback_read(char *buffer, size_t size, size_t nitems, SEXP fun)
   }
 
   size_t bytes_read = Rf_length(res);
-  memcpy(buffer, RAW(res), bytes_read);
+  if (bytes_read) memcpy(buffer, RAW_RO(res), bytes_read);
 
   UNPROTECT(3);
   return bytes_read;
@@ -73,7 +73,7 @@ int R_curl_callback_debug(CURL *handle, curl_infotype type_, char *data,
   /* wrap type and msg into R types */
   SEXP type = PROTECT(Rf_ScalarInteger(type_));
   SEXP msg = PROTECT(Rf_allocVector(RAWSXP, size));
-  memcpy(RAW(msg), data, size);
+  if (size) memcpy(RAW(msg), data, size);
 
   /* call the R function */
   SEXP call = PROTECT(Rf_lang3(fun, type, msg));
