@@ -8,18 +8,15 @@
 #include <string.h>
 #include <stdlib.h>
 
-#if LIBCURL_VERSION_MAJOR > 7 || (LIBCURL_VERSION_MAJOR == 7 && LIBCURL_VERSION_MINOR >= 28)
-#define HAS_MULTI_WAIT 1
-#endif
+#define make_string(x) x != NULL ? Rf_mkString(x) : Rf_ScalarString(NA_STRING)
+#define get_string(x) CHAR(STRING_ELT(x, 0))
+#define len_string(x) Rf_length(STRING_ELT(x, 0))
+#define assert(x) assert_message(x, NULL)
 
-#if LIBCURL_VERSION_MAJOR > 7 || (LIBCURL_VERSION_MAJOR == 7 && LIBCURL_VERSION_MINOR >= 55)
-#define USE_CURL_OFF_T 1
-#endif
 
-#ifndef DISABLE_CURL_EASY_OPTION
-#if LIBCURL_VERSION_MAJOR > 7 || (LIBCURL_VERSION_MAJOR == 7 && LIBCURL_VERSION_MINOR >= 73)
-#define HAS_CURL_EASY_OPTION 1
-#endif
+//RHEL-9 has curl 7.76.1
+#if CURL_AT_LEAST_VERSION(7,80,0)
+#define HAS_CURL_PARSER_STRERROR 1
 #endif
 
 typedef struct {
@@ -57,10 +54,10 @@ typedef struct {
 
 CURL* get_handle(SEXP ptr);
 reference* get_ref(SEXP ptr);
+void raise_libcurl_error(CURLcode res, reference *ref, SEXP error_cb);
 void assert_status(CURLcode res, reference *ref);
-void assert(CURLcode res);
+void assert_message(CURLcode res, const char *str);
 void massert(CURLMcode res);
-void stop_for_status(CURL *http_handle);
 SEXP slist_to_vec(struct curl_slist *slist);
 struct curl_slist* vec_to_slist(SEXP vec);
 struct curl_httppost* make_form(SEXP form);
@@ -79,3 +76,8 @@ SEXP make_handle_response(reference *ref);
 SEXP reflist_init(void);
 SEXP reflist_add(SEXP x, SEXP target);
 SEXP reflist_remove(SEXP x, SEXP target);
+
+/* Workaround for CRAN using outdated MacOS11 SDK */
+#if defined(__APPLE__) && defined(ENABLE_MACOS_POLYFILL) && !CURL_AT_LEAST_VERSION(7,81,0)
+#include "macos-polyfill.h"
+#endif
