@@ -7,6 +7,7 @@
 
 /* .Call calls */
 extern SEXP R_curl_connection(SEXP, SEXP, SEXP);
+extern SEXP R_curl_dryrun(SEXP);
 extern SEXP R_curl_escape(SEXP, SEXP);
 extern SEXP R_curl_fetch_disk(SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP R_curl_fetch_memory(SEXP, SEXP, SEXP);
@@ -28,16 +29,18 @@ extern SEXP R_handle_setform(SEXP, SEXP);
 extern SEXP R_handle_setheaders(SEXP, SEXP);
 extern SEXP R_handle_setopt(SEXP, SEXP, SEXP);
 extern SEXP R_option_types(void);
+extern SEXP R_modify_url(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP R_multi_add(SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP R_multi_cancel(SEXP);
 extern SEXP R_multi_fdset(SEXP);
 extern SEXP R_multi_list(SEXP);
 extern SEXP R_multi_new(void);
 extern SEXP R_multi_run(SEXP, SEXP, SEXP);
-extern SEXP R_multi_setopt(SEXP, SEXP, SEXP, SEXP);
+extern SEXP R_multi_setopt(SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP R_new_file_writer(SEXP);
 extern SEXP R_new_handle(void);
 extern SEXP R_nslookup(SEXP, SEXP);
+extern SEXP R_parse_url(SEXP, SEXP, SEXP);
 extern SEXP R_proxy_info(void);
 extern SEXP R_split_string(SEXP, SEXP);
 extern SEXP R_total_handles(void);
@@ -47,6 +50,7 @@ extern SEXP R_write_file_writer(SEXP, SEXP, SEXP);
 
 static const R_CallMethodDef CallEntries[] = {
     {"R_curl_connection",     (DL_FUNC) &R_curl_connection,     3},
+    {"R_curl_dryrun",         (DL_FUNC) &R_curl_dryrun,         1},
     {"R_curl_escape",         (DL_FUNC) &R_curl_escape,         2},
     {"R_curl_fetch_disk",     (DL_FUNC) &R_curl_fetch_disk,     5},
     {"R_curl_fetch_memory",   (DL_FUNC) &R_curl_fetch_memory,   3},
@@ -65,19 +69,20 @@ static const R_CallMethodDef CallEntries[] = {
     {"R_handle_getheaders",   (DL_FUNC) &R_handle_getheaders,   1},
     {"R_handle_reset",        (DL_FUNC) &R_handle_reset,        1},
     {"R_handle_setform",      (DL_FUNC) &R_handle_setform,      2},
-    {"R_handle_setheaders",   (DL_FUNC) &R_handle_setheaders,   2},
     {"R_handle_setopt",       (DL_FUNC) &R_handle_setopt,       3},
     {"R_option_types",        (DL_FUNC) &R_option_types,        0},
+    {"R_modify_url",          (DL_FUNC) &R_modify_url,          9},
     {"R_multi_add",           (DL_FUNC) &R_multi_add,           5},
     {"R_multi_cancel",        (DL_FUNC) &R_multi_cancel,        1},
     {"R_multi_fdset",         (DL_FUNC) &R_multi_fdset,         1},
     {"R_multi_list",          (DL_FUNC) &R_multi_list,          1},
     {"R_multi_new",           (DL_FUNC) &R_multi_new,           0},
     {"R_multi_run",           (DL_FUNC) &R_multi_run,           3},
-    {"R_multi_setopt",        (DL_FUNC) &R_multi_setopt,        4},
+    {"R_multi_setopt",        (DL_FUNC) &R_multi_setopt,        5},
     {"R_new_file_writer",     (DL_FUNC) &R_new_file_writer,     1},
     {"R_new_handle",          (DL_FUNC) &R_new_handle,          0},
     {"R_nslookup",            (DL_FUNC) &R_nslookup,            2},
+    {"R_parse_url",           (DL_FUNC) &R_parse_url,           3},
     {"R_proxy_info",          (DL_FUNC) &R_proxy_info,          0},
     {"R_split_string",        (DL_FUNC) &R_split_string,        2},
     {"R_total_handles",       (DL_FUNC) &R_total_handles,       0},
@@ -88,17 +93,17 @@ static const R_CallMethodDef CallEntries[] = {
 };
 
 void switch_to_openssl_on_vista(void);
-CURLM *multi_handle = NULL;
+CURLM *shared_multi_handle = NULL;
 
 attribute_visible void R_init_curl(DllInfo *info) {
   switch_to_openssl_on_vista();
   curl_global_init(CURL_GLOBAL_DEFAULT);
-  multi_handle = curl_multi_init();
+  shared_multi_handle = curl_multi_init();
   R_registerRoutines(info, NULL, CallEntries, NULL, NULL);
   R_useDynamicSymbols(info, FALSE);
 }
 
 attribute_visible void R_unload_curl(DllInfo *info) {
-  curl_multi_cleanup(multi_handle);
+  curl_multi_cleanup(shared_multi_handle);
   //curl_global_cleanup();
 }
