@@ -23,6 +23,15 @@ test_that("Auth username and password", {
   expect_equal(curl_fetch_memory(httpbin("digest-auth/auth/jerry/secret"), handle = h)$status, 200)
 })
 
+test_that("NetRC file works",{
+  skip_on_cran()
+  expect_equal(curl_fetch_memory(httpbin("basic-auth/user/yes"))$status, 401)
+  netrc <- tempfile(fileext = '.rc')
+  writeLines(c('default', ' login user', ' password yes'), netrc)
+  h <- new_handle(netrc = 1L, netrc_file = netrc)
+  expect_equal(curl_fetch_memory(httpbin("basic-auth/user/yes"), handle = h)$status, 200)
+})
+
 test_that("GC works", {
   gc()
   expect_equal(total_handles(), 0L)
