@@ -21,13 +21,14 @@ test_that("Cookies", {
 })
 
 test_that("Keep-Alive", {
-  # Connection to httpbin already set in previous tests. Subsequent requests
-  # should reuse the connection.
-  # Capture the verbose curl output to look for the connection reuse message
-  h <- handle_setopt(h, verbose=TRUE,
-    debugfunction=function(type, msg) cat(readBin(msg, character())))
-  req <- capture.output(curl_fetch_memory(httpbin("get"), handle=h))
-  expect_true(any(grepl("existing connection", req)))
+  con <- rawConnection(raw(), "wb")
+  handle_setopt(h, verbose=TRUE, debugfunction = function(type, msg){
+    if(type < 3) writeBin(msg, con)
+  })
+  req <- curl_fetch_memory(httpbin("get"), handle = h)
+  logs <- rawToChar(rawConnectionValue(con))
+  close(con)
+  expect_true(grepl("existing", logs))
   handle_setopt(h, verbose=FALSE)
 })
 
@@ -113,6 +114,7 @@ test_that("Set blank and NULL headers", {
 
 test_that("Custom vector options", {
   h <- new_handle()
+  skip_if_not('smtp' %in% curl_version()$protocols)
   x <- c("foo@gmail.com", "bar@jkhk.nl")
   handle_setopt(h, mail_rcpt = x)
   expect_equal(curl:::handle_getcustom(h), x)
@@ -135,14 +137,21 @@ test_that("Error classes", {
   expect_error(new_handle(http_version = 99999), 'http_version', class = 'curl_error_bad_function_argument')
   expect_error(curl_fetch_memory('https://asdfsdfsafdsfsdafsafssdfdsf.bla'), 'resolve', class = 'curl_error_couldnt_resolve_host')
   expect_error(curl_fetch_memory('https://asdfsdfsafdsfsdafsafssdfdsf.bla'), 'resolve', class = 'curl_error_couldnt_resolve_host')
-  expect_error(curl_fetch_memory('https://httpbin.org/delay/10', handle = new_handle(timeout = 1L)),
-               'Timeout was reached [httpbin.org]', class = 'curl_error_operation_timedout', fixed = TRUE)
 
   # NB: there is a bug in curl 8.7.1 (on e.g. macos) that causes failonerror
   # to throw 'curle_recv_error' instead of 'curle_http_returned_error'
   expect_error(curl_download('https://httpbin.org/status/418', 'output.txt'))
 })
 
+
+# This test was flaky with httpbin because of caching
+test_that("Timeout error", {
+  skip_on_cran()
+  # http://www2.census.gov/acs2011_5yr/pums/csv_pus.zip has cert issues
+  expect_error(curl_fetch_memory("https://sin-speed.hetzner.com/10GB.bin", handle = new_handle(timeout = 1L)),
+    'Timeout was reached [sin-speed.hetzner.com]', class = 'curl_error_operation_timedout', fixed = TRUE)
+})
+
 test_that("Platform specific features", {
   if(.Platform$OS.type == 'windows'){
     ssl_version <- curl_version()$ssl_version
